function [ A, width, fw_hm ] = PeakArea (X, Y, loc, a, b, AreaMode, BaseMode)
% PEAKAREA
%   Usage: [ A, width, fw_hm ] = PeakArea (X, Y, loc, a, b, AreaMode, BaseMode)
%
% PEAKAREA can be used for peak area integration  given the input signal
% (X,Y), the location 'loc' of the peak to be integrated (peak point's
% x-axis value), the x-axis limit (a,b) - peak endpoints, and the primary
% and secondary integration modes 'AreaMode' and 'BaseMode'.
%
% INPUT:
%   X           x-axis values of the input signal
%   Y           y-axis values of the input signal
%   loc         peak point location (x-axis value)
%   a           left-side peak endpoint
%   b           right-side peak endpoint
%   AreaMode    the method of integration for the region between the peak
%               endpoints and the baseline as determined by 'BaseMode':
%             - 'triangular'    computes the peak area as a triangular area
%                               between the three points that define the
%                               peak: the peak point and the two endpoints.
%             - 'fwhm'          computes the peak area using the triangular
%                               area method but at half maximum.
%             - 'polygon'       computes the area of the polygon as
%                               defined by the given region.
%             - 'trapezium'     trapezium method of integration.
%             - 'Simpsons'      Simpson's rule for integration.
%             - 'Gauss-Legendre' integration.
%             - 'Summation'     Simple summation of signal amplitude at
%                               each x-axis point within 'a' and 'b'.
%   BaseMode    the baseline definition
%             - 'End-to-End'    uses peak endpoint-to-endpoint as the
%                               baseline of the peak.
%             - 'Lower-end'     uses the lower endpoint of the peak to
%                               define a baseline parallel to the x-axis
%                               and as long as the distance of the
%                               endpoints in the x-coordinates.
%             - 'Baseline'      uses the x-axis as the baseline.
%
% OUTPUT: 
%   A           the computed area for the given region
%   width       the width of the peak base at the x-axis baseline.
%   fw_hm       a [1 x 3] vector containing the full width at half maximum
%               and the lead and trail x-axis points
%
%
% See also  FINDPEAKEDGES, FWHM, INTEGRAL, POLYAREA
%
% copyright 2006 by K. Veropoulos
% verop@dri.edu or k_veropoulos@freemail.gr
