function [ P, avg ] = detpeaks(y, varargin)
% DETPEAKS
%   Usage: [ P, avg ] = detpeaks(Y)
%          [ P, avg ] = detpeaks(Y, 'PropertyName', PropertyValue, ...)
%
% DETPEAKS can be used for peak detection of 1-D data. It returns the
% average peak amplitude (APA) in 'avg' and a vector 'P' containing the
% positions (indices) of all peaks in order of amplitude or position in the
% signal. The order (ascending or descending) can be determined by the
% value of the property 'order' (see property description below).
%
% INPUT: 
%   Y       1-D input signal
%   Properties:
%       'sort'          determines which measure to be used for sorting the
%                       found peaks and takes the values 'position' or
%                       'amplitude' (default: 'amplitude').
%       'order'         determines whether the sort order will ascending or
%                       descending and takes the values 'asc' and 'desc'.
%       'lowerlimit'    lower limit of peak amplitude or position
%                       (optional; default: minimum amplitude). If given
%                       value exceeds valid range of Y values or length,
%                       the default value is used.
%       'upperlimit'    upper limit of peak amplitude or position
%                       (optional; default: maximum amplitude). If given
%                       value exceeds valid range of Y values or length,
%                       the default value is used.
%       'endpeaks'      true/false (1/0) flag for including incomplete
%                       peaks at beginning and end of given signal
%                       (default: 0).
%
% OUTPUT: 
%   P       peak positions
%   avg     the average peak amplitude
%
%
% copyright 2006 by K. Veropoulos
% verop@dri.edu or k_veropoulos@freemail.gr
