% LOGINDLG   Dialog for visually secure login.
%   Examples:
%       [login password] = logindlg('Title','Login Title');  % Returns the
%       login and password with the dialog title 'Login Title'.
%
%       password = logindlg;  % Returns only the password with a default
%          dialog title.
%
%       password = logindlg('Password','only');  % Displays only a password
%          edit box and returns the password.
%
%       password = logindlg('Login',username);  % Displays the login dialog
%          with 'username' as default in the login edit box and returns the
%          password. 
%
%
%       To change the field labels use parameters 'Login_txt' and 'Pass_txt'.
%       This is useful if you want for example to change the default
%       field labels from 'Login' and 'Password' to 'Username' and 'Code'.
%
%
%
%
% Author: Jeremy Smith
% Date: September 24, 2005
% Last Edit: July 7, 2006
% Version: 1.2
% Tested on: Matlab 7.0.4.365 (R14) Service Pack 2 and Matlab 7.1 SP 3
% Description: custom login dialog because Matlab doesn't have an option
%       for characters in an edit field to be replaced by asterisks
%       (password security)

% Modified by K. Veropoulos
% Date: April 20, 2007
% Version: 1.3
% Tested on: Matlab 7.1.0.246 (R14) Service Pack 3

% Changelist:
%   1.3: -Improved input argument parsing (faster and not order specific
%           during argument parsing).
%        -Added more parameters to allow for user defined field labels.
%   1.2: -Tab no longer triggers the OK button in the password box
%        -Improved the script help
%        -Removed horizontal alignment from buttons
%        -Added the option to display only the password box
%   1.1: -Added positioning code so it'll display in the center of the screen
%        -If only one output is specified the password will be returned
%            instead of the login as in Version 1.0
%        -Escape will not only close the dialog if neither edit box is active
%        -When the dialog appears the first edit box will be active
%        -Added a few more comments
%        -Removed the clc, it was left in by mistake in Version 1.0