function [c,t] = uitoolfact(p,id)
%
%UITOOLFACT Creates built-in toolbar components
% uitoolfact 
%     With no arguments, displays registered toolbar 
%     components to the command window.
%
% [C] = uitoolfact(H,'GroupName.ComponentName') 
%     H is the parent toolbar handle. 
%     'GroupName' is the name of the toolbar group
%     'ComponentName' is the name of the toolbar component
%     C is the toolbar component
%
% [C] = uitoolfact(H,'GroupName')
%     Specifying a 'GroupName' without a 'ComponentName' will create
%     all the components, C, registered in that group.
%
% NOTE:
% C will return empty if the component is no longer supported as a
% built-in component.
%
% [INFO] = uitoolfact(H,'getinfo')
%     Returns a struct containing information on all registered tools.
%
% Example: 
%
%  % Create a figure with a simple toolbar
%  FIG = figure('toolbar','none');
%  H = uitoolbar('parent',FIG);
%  C = uitoolfact(H,'Standard.EditPlot'); 
%  C = uitoolfact(H,'Exploration.ZoomIn'); 
%  set(C,'Separator','on');
%  C = uitoolfact(H,'Exploration.ZoomOut');
%  C = uitoolfact(H,'Exploration.Pan');
%
% See also UITOOLFACTORY, UIGETTOOL.
%

%   modified by K.Veropoulos (kvero@dri.edu), October 2006
%   based on UITOOLFACTORY, Copyright 1984-2005 The MathWorks, Inc.