function [ GlobalAcc, ClassROC, ClassConfM, ClassAcc ] = CalcROCs ( D, Gids, Qids, thresh, Glabels, Qlabels )
%function CalcROCs: Calculate Receiver Operating Curves (ROCs)
%   [ GlobalAcc, ClassROC, ClassConfM, ClassAcc ] =
%                = CalcROCs ( D, Gids, Qids, thresh, Glabels, Qlabels )
%
% INPUT:
%       D:          distance matrix between the Query 'Q' and Gallery 'G' sets. 
%                   D(i,j) corresponds to the distance of Q(:,i) from G(:,j).
%       Gids:       IDs (persons) in 'G'.
%       Qids:       IDs (persons) in 'Q'.
%       thresh:     vector with threshold values.
%       Glabels:    labels (class ID) in 'G' (for class-specific
%                   verification - optional).
%       Qlabels:    labels (class ID) in 'Q' (for class-specific
%                   verification - optional).
%
% OUTPUT:
%       GlobalAcc:  individual results for all queries against
%                   the global gallery. 
%       ClassROC:   Average ROC graph over ROC of each class in queries
%                   against same class in the gallery (for class-specific
%                   verification only).
%       ClassConfM: Average Confusion Matrix over each class in queries
%                   against same class in the gallery (for class-specific
%                   verification only).
%       ClassAcc:   individual results for each class in queries against
%                   same class in the gallery (for class-specific
%                   verification only). 
%
%      ( Both 'GlobalAcc' and 'ClassAcc' are cell matrices each containing
%        3 tables: ROC points, Confusion Matrix, FIDs or False IDs.
%        See description of 'PerfTable' function ) 
%
% K. Veropoulos (k_veropoulos@freemail.gr)
% last updated Sep 22, 2006
