function HPars = ParsGrid (C_range, gamma_range)
%PARSGRID creates a set of all possible combinations of parameters C and
%gamma (grid) in HPars given a range of values (as 1xN vectors) for each 
%parameter. These values can be used (row by row) as a search grid for SVM
%optimization.
%
% USAGE:    HPars = ParsGrid ( C_range, gamma_range )
%
% INPUT:    C_range     - range of values for parameter C (cost) of C-SVC,
%                         epsilon-SVR, and nu-SVR in LibSVM as base 2
%                         exponents (*)
%           gamma_range - range of values for gamma in kernel function in
%                         LibSVM as base 2 exponents (*)
%
% OUTPUT:   HPars       - pairwise set of all possible combinations 
%                         (C, gamma)
%
% (*) e.g. C_range = [-5:15] is equivalent to 2^(-5), 2^(-4), ..., 2^15.
% Based on notes from the LibSVM guide on grid-search, trying exponentially
% growing sequences of C and gamma is a practical method to identify good
% parameters (http://www.csie.ntu.edu.tw/~cjlin/papers/guide/guide.pdf).
%
% See also: CSVM_OPT, CSVM_FS
%
%
% K. Veropoulos
% kvero@dri.edu or k_veropoulos@freemail.gr
