function model_opt = csvm_opt (Ttr, tr, varargin)
%CSVM_OPT performs an optimized C-SVM training on the data set 'tr'
%by applying cross-validation and grid-search to find the optimum
%parameters C and gamma (of the RBF kernel).
%
% USAGE:    model_opt = csvm_opt ( Ttr, tr )
%           model_opt = csvm_opt ( Ttr, tr, 'PropertyName', PropertyValue, ... )
%
% INPUT:    tr  - input samples (a MxN matrix of N samples of M variables)
%           Ttr - target values for each sample (a Nx1 matrix of N target
%                 values)
%           Properties (optional): Names -- Values
%           'C'         -- range of values for parameter C (cost) of C-SVC,
%                          epsilon-SVR, and nu-SVR in LibSVM as base 2
%                          exponents (default range: [-5:15])
%               example: model_opt = csvm_opt ( Ttr, tr, 'C', [-5:15])
%                  % will use 2^(-5), 2^(-4), ..., 2^14, 2^15 for C
%           'gamma'     -- range of values for parameter C (cost) of C-SVC,
%                          epsilon-SVR, and nu-SVR in LibSVM as base 2
%                          exponents (default range: [-15:3])
%               example: model_opt = csvm_opt ( Ttr, tr, 'gamma', [-15:3])
%                  % will use 2^(-15), 2^(-14), ..., 2^2, 2^3 for gamma
%           'quitemode' -- flag for output display. Values:
%                       'off'   display progress and results (default)
%                       'on'    use quite mode (do not display anything)
%
%   NOTE: if both C and gamma ranges are given scalars instead of vectors,
%         no optimization will be performed
%
% OUTPUT:   model_opt - optimised SVM model for the predictor to be used
%                       with function 'svm_predict'
%
% Ref: "A Practical Guide to Support Vector Classification"
%       by Chih-Wei Hsu, Chih-Chung Chang, and Chih-Jen Lin
%       (http://www.csie.ntu.edu.tw/~cjlin/papers/guide/guide.pdf)
%
%
% See also: PARSGRID, FEATSELS, CSVM_FS
%
% K. Veropoulos
% kvero@dri.edu or k_veropoulos@freemail.gr
