function [ Vtrue, Dtrue, sPCs ] = pcas( X, K, SIGMA, pinfo )
%PCAS calculates the principal components (sorted by largest magnitude
%eigenvalues) of a given matrix X.
%
% Usage: [ Vtrue, Dtrue, sPCs ] = pcas( X, K, SIGMA, pinfo )
%
% INPUT:        X - a (m x n) matrix where n is the number of samples
%               K - number of principal components to return
%           SIGMA - return K eigenvalues based on SIGMA (default 'LM'):
%                       'LM' or 'SM' - Largest or Smallest Magnitude
%                   For real symmetric problems, SIGMA may also be:
%                       'LA' or 'SA' - Largest or Smallest Algebraic
%                       'BE' - Both Ends, one more from high end if K is odd
%                   For nonsymmetric and complex problems, SIGMA may also be:
%                       'LR' or 'SR' - Largest or Smallest Real part
%                       'LI' or 'SI' - Largest or Smallest Imaginary part
%                   If SIGMA is a real or complex scalar including 0, EIGS
%                   finds the eigenvalues closest to SIGMA.  For scalar
%                   SIGMA, and also when SIGMA = 'SM' which uses the same
%                   algorithm as SIGMA = 0, B need only be symmetric (or
%                   Hermitian) positive semi-definite since it is not
%                   Cholesky factored as in the other cases.  
%           pinfo - The preserved information energy to use as condition
%                   for choosing the Significant Principal components
%                   (expressed in a scale between 0 and 1; default 1)   
%
% OUTPUT:   Vtrue - the principal components
%           Dtrue - the eigenvalues
%           sPCs  - a (n x 3) matrix holding the indices of the Significant
%                   Principal components, their equivalent cumulative
%                   information energy and their indices in their original
%                   order 
%   
% NOTE: The number of principal components computed will be based on 
%       K = min(K, R), where R = min(size(X)). If both 'K' and 'pinfo' are
%       given, then the number of returned principal components will be
%       based on the number of significant principal components that
%       satisfy the information energy as specified by 'pinfo'.
%   
%   
% See also: SVD, SVDS, EIG, EIGS, EIGS2, PRINCOMP, PCACOV, PCARES, KPCA1,
%           KPCA2, PCATK, CANONCORR, CCA, KCCA, KCCA2, KERNEL_MAT 
%
%
% copyright 2004-2006 by K. Veropoulos
% verop@unr.edu or k_veropoulos@freemail.gr
