function [predicted_label, accuracy, decisions_probs] = svmpredict(testing_label_vector, testing_instance_matrix, model, libsvm_options)
% SVMPREDICT: SVM Predictor
% 
% Usage: [predicted_label, accuracy, decision_values/prob_estimates] =
%           svmpredict(testing_label_vector, testing_instance_matrix, model, libsvm_options);
% 
% INPUT
% 	testing_label_vector        An m by 1 vector of prediction labels. If labels of test
%                               data are unknown, simply use any random values.
% 	testing_instance_matrix     An m by n matrix of m testing instances with n features.
%                               It can be dense or sparse.
% 	model                       The output of 'svmtrain'.
% 	libsvm_options              A string of testing options.
%     -b probability_estimates: whether to predict probability estimates, 0 or 1 (default 0); 
%                               one-class SVM not supported yet
% 
% OUTPUT
%   predicted_label             A vector of predicted labels.
%   accuracy                    A vector including accuracy (for classification), mean squared 
%                               error, and squared correlation coefficient (for regression).
%   decision_values/            decision values or probability estimates (if '-b 1' is specified). 
%   prob_estimates              If k is the number of classes, for decision values, 
%                               each row includes results of predicting k(k-1/2) binary-class SVMs. 
%                               For probabilities, each row contains k values indicating the probability 
%                               that the testing instance is in each class. Note that the order of 
%                               classes here is the same as 'Label' field in the model structure.
% 
% See also: SVMTRAIN, CSVM_OPT, CSVM_FS, PARSGRID, FEATSELS
% 
% LIBSVM written by Chih-Chung Chang and Chih-Jen Lin (http://www.csie.ntu.edu.tw/~cjlin/libsvm)
% MATLAB Interface written by Jun-Cheng Chen, Kuan-Jen Peng, Chih-Yuan Yang and Chih-Huai Cheng
% 
% modified by K. Veropoulos for KV_LIB
% (kvero@dri.edu or k_veropoulos@freemail.gr)
% 
