function outstr = repstr( instr, M, N )
%REPSTR (repeat string) takes an input string 'instr' and repeats it
%MxN times. If one number of repetitions is given the output 'outstr' is a
%string with 'instr' concatenated horizontally that many times. Useful when
%someone wants to create an empty string of length N. If two numbers are
%given (in a similar way as in zeros(...) or ones(...) functions, ie.
%number of rows and number of columns), then the output is a cell array of
%strings of size MxN, unless the second number (number of columns) is one,
%in which case the function returns a string (similar to one number input).
%
% Usage: outstr = repstr( instr, M, N )
%
% INPUT 
%   instr   an input character or string to be repeated
%   M       number of rows to repeat 'instr'
%   N       number of columns to repeat 'instr'
%
% OUTPUT
%   outstr  the resulting string
%
% EXAMPLES
%       % create an empty string of length 20
%       % S2 = '                    '
%       S1 = ' ';
%       S2 = repstr(S1,20); 
%
%       % create a text line with 60 dashes
%       % S2 = '------------------------------------------------------------'
%       S2 = repstr('-',60);
%
%     >> S3 = repstr('test',2,2)
% 
%     S3 = 
% 
%         'test'    'test'
%         'test'    'test'
% 
%     >> S3 = repstr('test',1,2)
% 
%     S3 = 
% 
%         'test'    'test'
% 
%     >> S3 = repstr('test',2,1)
% 
%     S3 =
% 
%     test
%     test
%
%     >> S3 = repstr('test',2,1)'
% 
%     S3 =
% 
%     tt
%     ee
%     ss
%     tt
%
%
% K. Veropoulos
% kvero@dri.edu or k_veropoulos@freemail.gr
