function IDBMS
%--------------------------------------------------------------------------
% Image Database Management System (IDBMS)
% ========================================
% 
% FUNCTIONS
%
% Select data file:       select the data file (create/change) in which
%                         all the images will be stored.
%
% Select source folder:   select the folder containing all the images of
%                         the same class
%
% Select source image:    select a single image file for inclusion in a
%                         class
%
% Normalize Images:       Based on the given markers file, this function
%                         will find the average marker points from the
%                         whole set of images and normalize each image
%                         based on the transformation of its associated
%                         marker points to the average markers of the whole
%                         set.
%
%                         markers file:the file that contains the
%                         coordinates of the face marker points. The
%                         coordinates should be separated by space and in
%                         the following order:
%                         <LEFT EYE> <RIGHT EYE> <NOSE> <MOUTH>
%                         e.g. 292 312 166 308 226 382 226 452
%                         All the images will be normalized and cropped based 
%                         on the average values of these coordinates.
%
% Crop images:            Crop images to be stored in the database using
%                         two user-defined numbers that serve as an
%                         expansion to the two directions (width height,
%                         respectively) of the rectangle as defined by the
%                         face marker points.
%
% Resize images:          Resize images to be stored in the database by a
%                         user-defined factor
%
% Add images to database: all the images in the selected folder are added
%                         to the database that will be used for training
%                         and testing 
%
% Remove images from database:
%                         remove classes or a randomly selected
%                         user-defined number of images from the database. 
%
% Merge classes in database:
%                         merge a number of classes in the database.
%
% Database Info:          show information about the images present in
%                         database. Images must have the same size. If this
%                         is not true you have to resize them.
%
% Database Preview:       show small sample of images
%
% Delete Database:        remove database from the current directory
%
% Cross-Validation:
%                         generate k-fold cross-validation sets; the
%                         resulting data file will have the original data
%                         split into k-folds from which k pairs of training
%                         and test sets will be generated with sizes
%                         (datasize-datasize/k) and (datasize/k)
%                         respectively. A validation set will be randomly
%                         selected from the training set using the
%                         'classify' function. 
%
% Info:                   show information about this software
%
% Exit:                   quit program
%
%--------------------------------------------------------------------------
% NOTE: All resulting matlab files contain data matrices with vector images
%       represented in columns.
%--------------------------------------------------------------------------
%
% Author: K. Veropoulos, <verop@unr.edu> 
% last updated Feb 14, 2006
