function [X, map, alpha] = iread( filename, format )
%%#function checknargin checkinput
%IREAD Read image from graphics file.
%   A = IREAD(FILENAME,FMT) reads the image in FILENAME into
%   A. If the file contains a grayscale intensity image, A is
%   a two-dimensional array.  If the file contains a truecolor
%   (RGB) image, A is a three-dimensional (M-by-N-by-3) array.
%   FILENAME is a string that specifies the name of the
%   graphics file, and FMT is a string that specifies the
%   format of the file.  The file must be in the current
%   directory or in a directory on the MATLAB path.  If IREAD
%   cannot find a file named FILENAME, it looks for a file
%   named FILENAME.FMT.
%
%   The possible values for FMT are found in the image file format
%   registry, IMFORMATS.
%
%   [X,MAP] = IREAD(FILENAME,FMT) reads the indexed image in
%   FILENAME into X and its associated colormap into MAP.
%   Colormap values in the image file are automatically
%   rescaled into the range [0,1]. 
%
%   [...] = IREAD(FILENAME) attempts to infer the format of the
%   file from its content.
%
%   Data types
%   ----------
%   In most of the image file formats supported by IREAD,
%   pixels are stored using 8 or fewer bits per color plane.
%   If the file contains only 1 bit per pixel, the class of the
%   output (A or X) is logical.  When reading other files with
%   8 or fewer bits per color plane, the class of the output
%   is uint8.  IREAD also supports reading 16-bit-per-pixel
%   data from BMP, TIFF and PNG files. For 16-bit TIFF and PNG
%   image files, the class of the output (A or X) is uint16 and
%   for 16-bit BMP image files, the class of the output is uint8.
%
%   Supported file types
%   --------------------
%   JPEG  Any baseline JPEG image; JPEG images with some
%         commonly used extensions
%
%   TIFF  Any baseline TIFF image, including 1-bit, 8-bit, and
%         24-bit uncompressed images; 1-bit, 8-bit, and 24-bit
%         images with packbits compression; 1-bit images with
%         CCITT compression; also, 16-bit grayscale, 16-bit
%         indexed, and 48-bit RGB images
%
%   GIF   Any 1-bit to 8-bit GIF image
%
%   BMP   1-bit, 4-bit, 8-bit, 16-bit, 24-bit, and 32-bit uncompressed
%         images; 4-bit and 8-bit run-length encoded (RLE) images
%
%   PNG   Any PNG image, including 1-bit, 2-bit, 4-bit, 8-bit,
%         and 16-bit grayscale images; 8-bit and 16-bit
%         indexed images; 24-bit and 48-bit RGB images
%
%   HDF   8-bit raster image datasets, with or without an
%         associated colormap; 24-bit raster image datasets
%
%   PCX   1-bit, 8-bit, and 24-bit images
%
%   XWD   1-bit and 8-bit ZPixmaps; XYBitmaps; 1-bit XYPixmaps
%
%   ICO   1-bit, 4-bit, and 8-bit uncompressed images
%
%   CUR   1-bit, 4-bit, and 8-bit uncompressed images
%
%   RAS   Any RAS image, including 1-bit bitmap, 8-bit indexed,
%         24-bit truecolor and 32-bit truecolor with alpha.
%
%   PBM   Any 1-bit PBM image.  Raw (binary) or ASCII (plain) encoded.
%
%   PGM   Any standard PGM image.  ASCII (plain) encoded with
%         arbitrary color depth.  Raw (binary) encoded with up
%         to 16 bits per gray value.
%
%   PPM   Any standard PPM image.  ASCII (plain) encoded with
%         arbitrary color depth. Raw (binary) encoded with up
%         to 16 bits per color component.
%
% Adapted from imread function of
%   Steven L. Eddins, June 1996
%   Copyright 1984-2002 The MathWorks, Inc.
%   $Revision: 1.31 $  $Date: 2002/04/19 14:18:23 $
%
% Modified by K. Veropoulos
% Date: Sep 2004
% verop@unr.edu, k_veropoulos@freemail.gr
