function A = iresize( A, m, method, h )
%IRESIZE Resize image.
%   IRESIZE resizes an image of any type using the specified
%   interpolation method. Supported interpolation methods
%   include:
%
%        'nearest'  (default) nearest neighbor interpolation
%
%        'bilinear' bilinear interpolation
%
%        'bicubic'  bicubic interpolation
%
%   B = IRESIZE(A,[MROWS MCOLS],METHOD) returns an image of size
%   MROWS-by-MCOLS. If the specified size does not produce the
%   same aspect ratio as the input image has, the output image is
%   distorted.
%
%   When the specified output size is smaller than the size of
%   the input image, and METHOD is 'bilinear' or 'bicubic',
%   IRESIZE applies a lowpass filter before interpolation to
%   reduce aliasing. The default filter size is 11-by-11.
%
%   You can specify a different order for the default filter
%   using:
%
%        [...] = IRESIZE(...,METHOD,N)
%
%   N is an integer scalar specifying the size of the filter,
%   which is N-by-N. If N is 0, IRESIZE omits the filtering
%   step.
%
%   Class Support
%   -------------
%   The input image A can be numeric or logical and it must be 
%   nonsparse. The output image is of the same class as the 
%   input image.
%
% Adapted from MathWorks' imresize function
%   Copyright 1993-2002 The MathWorks, Inc.  
%   $Revision: 5.30 $  $Date: 2002/03/28 21:32:58 $
%
% Modified by K. Veropoulos
% Date: Sep 2004
% verop@unr.edu, k_veropoulos@freemail.gr
